@@ -6,7 +6,7 @@
  *    Sean Atkinson <sca20@cam.ac.uk>
  **/
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include "xbase.h"
 
@@ -24,6 +24,8 @@
 #include <sheet-style.h>
 #include <io-context.h>
 
+#include <stdlib.h>
+
 GNUMERIC_MODULE_PLUGIN_INFO_DECL;
 
 void xbase_file_open (GnmFileOpener const *fo, IOContext *io_context,
@@ -193,6 +195,14 @@ xbase_file_open (GnmFileOpener const *fo, IOContext *io_context,
 	record = record_new (file);
 	row = 1;
 	do {
+		if (row >= SHEET_MAX_ROWS) {
+			g_warning (_("This build of Gnumeric can only hold %d "
+				   "rows.  Ignoring the rest of this file.  You "
+				   "will need a custom build with SHEET_MAX_ROWS "
+				   "increased to read this file."),
+				   SHEET_MAX_ROWS);
+			break;
+		}
 		for (i = 0; i < file->fields ; i++) {
 			field = record->file->format [i];
 			val = xbase_field_as_value (
