@@ -2,7 +2,7 @@
 /*
  * go-data-impl.h : 
  *
- * Copyright (C) 2003 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -30,7 +30,8 @@ G_BEGIN_DECLS
 typedef enum {
 	GO_DATA_CACHE_IS_VALID =	1 << 0,
 	GO_DATA_IS_EDITABLE =		1 << 1,
-	GO_DATA_VECTOR_LEN_CACHED =	1 << 2
+	GO_DATA_VECTOR_LEN_CACHED =	1 << 2,
+	GO_DATA_MATRIX_SIZE_CACHED = GO_DATA_VECTOR_LEN_CACHED
 } GODataFlags;
 
 struct _GOData {
@@ -51,9 +52,6 @@ typedef struct {
 	void (*changed)	(GOData *dat);
 } GODataClass;
 
-/* protected */
-void go_data_emit_changed (GOData *dat);
-
 struct _GODataScalar {
 	GOData base;
 };
@@ -82,6 +80,24 @@ typedef struct {
 /*	PangoLayout *(get_fmt_str)  (GODataVector *vec, unsigned i); */
 } GODataVectorClass;
 
+struct _GODataMatrix {
+	GOData base;
+
+	GOMatrixSize size;	/* negative if dirty, includes missing values */
+	double *values;	/* NULL = uninitialized/unsupported, nan = missing */
+	double minimum, maximum;
+};
+
+typedef struct {
+	GODataClass base;
+
+	void	 (*load_size)    (GODataMatrix *vec);
+	void	 (*load_values) (GODataMatrix *vec);
+	double	 (*get_value)   (GODataMatrix *mat, unsigned i, unsigned j);
+	char	*(*get_str)	(GODataMatrix *mat, unsigned i, unsigned j);
+/*	PangoLayout *(get_fmt_str)  (GODataMatrix *mat, unsigned i, unsigned j); */
+} GODataMatrixClass;
+
 G_END_DECLS
 
 #endif /* GO_DATA_IMPL_H */
