@@ -5,7 +5,7 @@
 #include "format-template.h"
 
 GSList  *category_group_get_templates_list (FormatTemplateCategoryGroup *category_group,
-					    CommandContext *context);
+					    GnmCmdContext *context);
 
 GList   *category_group_list_get (void);
 void     category_group_list_free (GList *category_groups);
