@@ -30,6 +30,7 @@
 #include "cell.h"
 #include "style.h"
 #include "style-color.h"
+#include "style-font.h"
 #include "number-match.h"
 #include "sheet.h"
 #include "sheet-merge.h"
@@ -45,6 +46,7 @@
 #include <string.h>
 
 #define BUG_105322
+#undef DEBUG_BOUNDING_BOX
 
 #ifndef USE_RV_POOLS
 #define USE_RV_POOLS 1
@@ -60,6 +62,7 @@ static GnmMemChunk *rendered_value_pool;
 #define CHUNK_FREE(p,v) g_free ((v))
 #endif
 
+
 static guint16
 calc_indent (PangoContext *context, const GnmStyle *mstyle, Sheet *sheet)
 {
@@ -111,9 +114,11 @@ rendered_value_render (GString *str,
 		GnmFormat *format = mstyle_get_format (mstyle);
 
 		/* For format general approximate the cell width in characters */
-		if (style_format_is_general (format)) {
-			is_variable_width = (VALUE_FMT (cell->value) == NULL ||
-					     style_format_is_general (VALUE_FMT (cell->value)));
+		if (style_format_is_var_width (format)) {
+			gboolean is_rotated = (mstyle_get_rotation (mstyle) != 0);
+			is_variable_width = !is_rotated &&
+				(VALUE_FMT (cell->value) == NULL ||
+				 style_format_is_var_width (VALUE_FMT (cell->value)));
 			if (is_variable_width && allow_variable_width) {
 				GnmFont *style_font =
 					scg_get_style_font (context, sheet, mstyle);
@@ -144,7 +149,7 @@ rendered_value_render (GString *str,
 					col_width = cell_width / wdigit;
 				}
 				style_font_unref (style_font);
-			} else
+			} else if (style_format_is_general (format))
 				format = VALUE_FMT (cell->value);
 		}
 		format_value_gstring (str, format, cell->value, color,
@@ -171,12 +176,72 @@ cb_dump (PangoAttribute *a)
 				(PangoAttrFilterFunc) cb_dump, NULL);
 #endif
 
+#ifdef HAVE_PANGO_CONTEXT_SET_MATRIX
+/* Gets the bounds of a layout in pango units.  Mostly copied from gtklabel.c */
+static void
+get_rotated_layout_bounds (PangoLayout *layout, int *width, int *height)
+{
+	PangoContext *context = pango_layout_get_context (layout);
+	const PangoMatrix *matrix = pango_context_get_matrix (context);
+	gdouble x_min = 0, x_max = 0, y_min = 0, y_max = 0; /* quiet gcc */
+	PangoRectangle logical_rect;
+	gint i, j;
+
+	pango_layout_get_extents (layout, NULL, &logical_rect);
+
+	for (i = 0; i < 2; i++)
+	{
+		gdouble x = (i == 0) ? logical_rect.x : logical_rect.x + logical_rect.width;
+		for (j = 0; j < 2; j++)
+		{
+			gdouble y = (j == 0) ? logical_rect.y : logical_rect.y + logical_rect.height;
+
+			gdouble xt = (x * matrix->xx + y * matrix->xy) + matrix->x0 * PANGO_SCALE;
+			gdouble yt = (x * matrix->yx + y * matrix->yy) + matrix->y0 * PANGO_SCALE;
+
+			if (i == 0 && j == 0)
+			{
+				x_min = x_max = xt;
+				y_min = y_max = yt;
+			}
+			else
+			{
+				if (xt < x_min)
+					x_min = xt;
+				if (yt < y_min)
+					y_min = yt;
+				if (xt > x_max)
+					x_max = xt;
+				if (yt > y_max)
+					y_max = yt;
+			}
+		}
+	}
+
+	*width = ceil (x_max) - floor (x_min);
+	*height = ceil (y_max) - floor (y_min);
+}
+#endif
+
 void
 rendered_value_remeasure (RenderedValue *rv)
 {
-	pango_layout_get_size (rv->layout,
-			       &rv->layout_natural_width,
-			       &rv->layout_natural_height);
+#ifdef HAVE_PANGO_CONTEXT_SET_MATRIX
+	if (rv->rotation) {
+		PangoMatrix rotmat = PANGO_MATRIX_INIT;
+		PangoContext *context = pango_layout_get_context (rv->layout);
+
+		pango_matrix_rotate (&rotmat, rv->rotation);
+		pango_context_set_matrix (context, &rotmat);
+		pango_layout_context_changed (rv->layout);
+		get_rotated_layout_bounds (rv->layout, &rv->layout_natural_width, &rv->layout_natural_height);
+		pango_context_set_matrix (context, NULL);
+		pango_layout_context_changed (rv->layout);
+	} else
+#endif
+		pango_layout_get_size (rv->layout,
+				       &rv->layout_natural_width,
+				       &rv->layout_natural_height);
 }
 
 
@@ -236,7 +301,11 @@ rendered_value_new (GnmCell *cell, GnmStyle const *mstyle,
 	res->wrap_text = mstyle_get_effective_wrap_text (mstyle);
 	res->effective_halign = style_default_halign (mstyle, cell);
 	res->effective_valign = mstyle_get_align_v (mstyle);
-	res->display_formula = display_formula;
+	res->rotation = mstyle_get_rotation (mstyle);
+	res->might_overflow =
+		cell_is_number (cell) &&
+		!display_formula &&
+		mstyle_get_rotation (mstyle) == 0;
 
 	res->layout = layout = pango_layout_new (context);
 	pango_layout_set_text (layout, str->str, str->len);
@@ -265,6 +334,21 @@ rendered_value_new (GnmCell *cell, GnmStyle const *mstyle,
 	}
 #endif
 
+#ifdef DEBUG_BOUNDING_BOX
+	{
+		PangoAttrList *new_attrs = pango_attr_list_copy (attrs);
+		PangoAttribute *attr;
+
+		pango_attr_list_unref (attrs);
+		attrs = new_attrs;
+		attr = pango_attr_background_new (0xffff, 0, 0);
+		attr->start_index = 0;
+		attr->end_index = -1;
+		pango_attr_list_insert (attrs, attr);
+		style_color_unref (color);
+	}
+#endif
+
 	if (cell->value != NULL) {
 		GnmFormat const *fmt = VALUE_FMT (cell->value);
 		if (fmt != NULL && style_format_is_markup (fmt)) {
@@ -376,7 +460,7 @@ rendered_value_recontext (RenderedValue *rv, PangoContext *context)
 const char *
 rendered_value_get_text (RenderedValue const *rv)
 {
-	g_return_val_if_fail (rv != NULL, g_strdup ("ERROR"));
+	g_return_val_if_fail (rv != NULL, "ERROR");
 	return pango_layout_get_text (rv->layout);
 }
 
@@ -473,19 +557,35 @@ cell_get_entered_text (GnmCell const *cell)
 	return g_strdup ("<ERROR>");
 }
 
+/*
+ * Return the height of the rendered layout after rotation.
+ */
 int
 cell_rendered_height (GnmCell const *cell)
 {
-	if (!cell || !cell->rendered_value)
+	const RenderedValue *rv;
+
+	g_return_val_if_fail (cell != NULL, 0);
+
+	rv = cell->rendered_value;
+	if (!rv)
 		return 0;
 
 	return PANGO_PIXELS (cell->rendered_value->layout_natural_height);
 }
 
+/*
+ * Return the width of the rendered layout after rotation.
+ */
 int
 cell_rendered_width (GnmCell const *cell)
 {
-	if (!cell || !cell->rendered_value)
+	const RenderedValue *rv;
+
+	g_return_val_if_fail (cell != NULL, 0);
+
+	rv = cell->rendered_value;
+	if (!rv)
 		return 0;
 
 	return PANGO_PIXELS (cell->rendered_value->layout_natural_width);
