@@ -1644,6 +1644,8 @@ scg_cursor_visible (SheetControlGUI *scg, gboolean is_visible)
 static gboolean
 scg_mode_clear (SheetControlGUI *scg)
 {
+	WorkbookControl *wbc;
+
 	g_return_val_if_fail (IS_SHEET_CONTROL_GUI (scg), FALSE);
 
 	if (scg->new_object != NULL) {
@@ -1651,7 +1653,9 @@ scg_mode_clear (SheetControlGUI *scg)
 		scg->new_object = NULL;
 	}
 	scg_object_unselect (scg, NULL);
-	wb_control_update_action_sensitivity (sc_wbc (SHEET_CONTROL (scg)));
+	wbc = sc_wbc (SHEET_CONTROL (scg));
+	if (wbc != NULL) /* during destruction */
+		wb_control_update_action_sensitivity (wbc);
 
 	return TRUE;
 }
@@ -1948,10 +1952,15 @@ cb_collect_objects_to_commit (SheetObject *so, double *coords, CollectObjectsDat
 			if (NULL != ctrl_pts[9]) {
 				double const *pts = g_hash_table_lookup (
 					pane->gcanvas->simple.scg->selected_objects, so);
+				SheetObjectView *sov = sheet_object_get_view (so,
+					(SheetObjectViewContainer *)pane);
+
 				gtk_object_destroy (GTK_OBJECT (ctrl_pts[9]));
 				ctrl_pts[9] = NULL;
-				sheet_object_view_set_bounds (sheet_object_get_view (so, (SheetObjectViewContainer *)pane),
-					pts, TRUE);
+
+				if (NULL == sov)
+					sov = sheet_object_new_view (so, (SheetObjectViewContainer *)pane);
+				sheet_object_view_set_bounds (sov, pts, TRUE);
 			}
 		});
 	}
