@@ -80,10 +80,14 @@ cb_so_delete (SheetObject *so, SheetControl *sc)
 	cmd_objects_delete (sc_wbc (sc), 
 		gnm_slist_create (so, NULL), NULL);
 }
-static void
-cb_so_configure (SheetObject *so, SheetControl *sc)
+void
+sheet_object_get_editor (SheetObject *so, SheetControl *sc)
 {
-	SO_CLASS(so)->user_config (so, sc);
+	g_return_if_fail (IS_SHEET_OBJECT (so));
+	g_return_if_fail (SO_CLASS (so));
+
+	if (SO_CLASS(so)->user_config)
+		SO_CLASS(so)->user_config (so, sc);
 }
 static void
 cb_so_cut (SheetObject *so, SheetControl *sc)
@@ -102,7 +106,7 @@ static void
 sheet_object_populate_menu (SheetObject *so, GPtrArray *actions)
 {
 	static SheetObjectAction const so_actions [] = {
-		{ "gtk-properties",	NULL,		NULL,  0, cb_so_configure },
+		{ "gtk-properties",	NULL,		NULL,  0, sheet_object_get_editor },
 		{ NULL,	NULL, NULL, 0, NULL },
 		{ NULL,			N_("_Order"),	NULL,  1, NULL },
 			{ NULL,			N_("Pul_l to Front"),	NULL,  0, cb_so_pull_to_front },
@@ -294,6 +298,15 @@ sheet_object_get_sheet (SheetObject const *so)
 	return so->sheet;
 }
 
+static int
+cb_create_views (SheetObject *so)
+{
+	g_object_set_data (G_OBJECT (so), "create_view_handler", NULL);
+	SHEET_FOREACH_CONTROL (so->sheet, view, control,
+		sc_object_create_view (control, so););
+	sheet_object_update_bounds (so, NULL);
+	return FALSE;
+}
 
 /**
  * sheet_object_set_sheet :
@@ -321,13 +334,14 @@ sheet_object_set_sheet (SheetObject *so, Sheet *sheet)
 
 	g_object_ref (G_OBJECT (so));
 	sheet->sheet_objects = g_list_prepend (sheet->sheet_objects, so);
-	SHEET_FOREACH_CONTROL (so->sheet, view, control,
-		sc_object_create_view (control, so););
-	sheet_object_update_bounds (so, NULL);
-
 	/* FIXME : add a flag to sheet to have sheet_update do this */
 	sheet_objects_max_extent (sheet);
 
+	if (NULL == g_object_get_data (G_OBJECT (so), "create_view_handler")) {
+		guint id = g_idle_add ((GSourceFunc) cb_create_views, so);
+		g_object_set_data (G_OBJECT (so), "create_view_handler", GUINT_TO_POINTER (id));
+	}
+
 	return FALSE;
 }
 
@@ -344,6 +358,7 @@ gboolean
 sheet_object_clear_sheet (SheetObject *so)
 {
 	GList *ptr;
+	gpointer view_handler;
 
 	g_return_val_if_fail (IS_SHEET_OBJECT (so), TRUE);
 	g_return_val_if_fail (IS_SHEET (so->sheet), TRUE);
@@ -351,6 +366,13 @@ sheet_object_clear_sheet (SheetObject *so)
 	ptr = g_list_find (so->sheet->sheet_objects, so);
 	g_return_val_if_fail (ptr != NULL, TRUE);
 
+	/* clear any pending attempts to create views */
+	view_handler = g_object_get_data (G_OBJECT (so), "create_view_handler");
+	if (NULL != view_handler) {
+		g_source_remove (GPOINTER_TO_UINT (view_handler));
+		g_object_set_data (G_OBJECT (so), "create_view_handler", NULL);
+	}
+
 	/* The views remove themselves from the list */
 	while (so->realized_list != NULL)
 		sheet_object_view_destroy (so->realized_list->data);
@@ -387,21 +409,21 @@ cb_sheet_object_view_finalized (SheetObject *so, GObject *view)
  *
  * Asks @so to create a view for the (@sc,@key) pair.
  **/
-void
+SheetObjectView *
 sheet_object_new_view (SheetObject *so, SheetObjectViewContainer *container)
 {
 	SheetObjectView *view;
 
-	g_return_if_fail (IS_SHEET_OBJECT (so));
-	g_return_if_fail (NULL != container);
+	g_return_val_if_fail (IS_SHEET_OBJECT (so), NULL);
+	g_return_val_if_fail (NULL != container, NULL);
 
 	view = sheet_object_get_view (so, container);
 	if (view != NULL)
-		return;
+		return NULL;
 
 	view = SO_CLASS (so)->new_view (so, container);
 
-	g_return_if_fail (IS_SHEET_OBJECT_VIEW (view));
+	g_return_val_if_fail (IS_SHEET_OBJECT_VIEW (view), NULL);
 
 	/* Store some useful information */
 	g_object_set_qdata (G_OBJECT (view), sov_so_quark, so);
@@ -410,6 +432,8 @@ sheet_object_new_view (SheetObject *so, SheetObjectViewContainer *container)
 		(GWeakNotify) cb_sheet_object_view_finalized, so);
 	so->realized_list = g_list_prepend (so->realized_list, view);
 	sheet_object_update_bounds (so, NULL);
+
+	return view;
 }
 
 gboolean
@@ -869,8 +893,12 @@ void
 sheet_object_view_set_bounds (SheetObjectView *sov,
 			      double const *coords, gboolean visible)
 {
-	SheetObjectViewIface *iface = SHEET_OBJECT_VIEW_GET_CLASS (sov);
-	iface->set_bounds (sov, coords, visible);
+	SheetObjectViewIface *iface;
+	
+	g_return_if_fail (IS_SHEET_OBJECT_VIEW (sov));
+	iface = SHEET_OBJECT_VIEW_GET_CLASS (sov);
+	if (NULL != iface->set_bounds)
+		(iface->set_bounds) (sov, coords, visible);
 }
 
 SheetObject *
