@@ -23,7 +23,7 @@
 */
 
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include "reports.h"
 
 #include "format.h"
@@ -128,7 +128,6 @@ is_still_feasible (Sheet *sheet, SolverResults *res, int col, gnm_float value)
 			break;
 		case SolverINT:
 		case SolverBOOL:
-		case SolverOF:
 		        break;
 		}
 	}
